@@ -1287,7 +1287,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1383,7 +1382,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1695,6 +1693,7 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1868,7 +1867,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Belize", "Belize" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Kajm\u00e1n-szigetek" },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "timezone.excity.America/Dawson", "Dawson" },
@@ -1880,7 +1878,6 @@ public class TimeZoneNames_hu extends TimeZoneNamesBundle {
             { "timezone.excity.America/La_Paz", "La Paz" },
             { "timezone.excity.America/Maceio", "Macei\u00f3" },
             { "timezone.excity.America/Manaus", "Manaus" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.America/Nassau", "Nassau" },
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.America/Recife", "Recife" },
